@@ -17,6 +17,13 @@ COMPANY_CIK_NAME_QUERY = '''
         }
     }'''
 
+COMPANY_CIK_TICKER_QUERY = '''
+    query {
+        companies{
+            cik
+            ticker
+        }
+    }'''
 
 DATASET_QUERY = lambda name, api_key : '''
     query {
